@@ -9,12 +9,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 	/* ------------------------------------------------------------
@@ -267,9 +267,9 @@ int addcall2(void)
     } else
 	i = found;
 
-    strncpy(zonebuffer, cqzone, 3);	//hack: getctydata should not change zone!
+    g_strlcpy(zonebuffer, cqzone, 4);	//hack: getctydata should not change zone!
     j = getctydata2(hiscall);
-    strncpy(cqzone, zonebuffer, 3);	//idem....
+    g_strlcpy(cqzone, zonebuffer, 4);	//idem....
 
     call_country[i] = j;
     if (strlen(comment) >= 1) {
@@ -389,7 +389,9 @@ int addcall2(void)
 	if (lan_logline[68] != ' ') {
 
 	    strcpy(lancopy, "     ");
-	    strncpy(lancopy, lan_logline + 68, 4);
+
+	    /* max 5 char for prefix written in makelogline */
+	    strncpy(lancopy, lan_logline + 68, 5);
 
 	    for (p = 0; p <= 5; p++) {	// terminate at first space
 
