@@ -10,12 +10,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 	/* ------------------------------------------------------------
@@ -27,11 +27,14 @@
 #include "addspot.h"
 #include "changefreq.h"
 #include "bandmap.h"
-#include "glib.h"
+#include <glib.h>
+#include "cw_utils.h"
 
 #define TUNE_UP 6	/* tune up for 6 s (no more than 10) */
 
 void send_bandswitch(int freq);
+int autosend(void);
+int plain_number(char *str);
 
 /** callsign input loop
  *
@@ -47,7 +50,6 @@ char callinput(void)
     extern int dxped;
     extern int cwstart;
     extern int early_started;
-    extern int sending_call;
     extern char hiscall[];
     extern char hiscall_sent[];
     extern char comment[];
@@ -58,8 +60,6 @@ char callinput(void)
     extern char lastcall[];
     extern char band[9][4];
     extern int bandinx;
-    extern char speedstr[];
-    extern int keyspeed;
     extern int cqdelay;
     extern char his_rst[];
     extern char backgrnd_str[];
@@ -67,7 +67,7 @@ char callinput(void)
     extern int cluster;
     extern int announcefilter;
     extern char buffer[];
-    extern char message[15][80];
+    extern char message[][80];
     extern char ph_message[14][80];
     extern float freq;
     extern float mem;
@@ -106,8 +106,6 @@ char callinput(void)
     int i, j, ii, rc, t, x = 0, y = 0;
     char instring[2] = { '\0', '\0' };
     char dupecall[17];
-    char speedbuf[3] = "";
-    char weightbuf[5];
     static int lastwindow;
 
 
@@ -157,7 +155,7 @@ char callinput(void)
 		    cqmode = CQ;
 
 		/* and show new mode */
-		attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+		attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 
 		if (cqmode == CQ) {
 		    mvprintw(0, 2, "Log     ");
@@ -187,13 +185,13 @@ char callinput(void)
 
 	    if (x == '=' && *hiscall == '\0') {
 		strcat(buffer, lastcall);
-		strcat(buffer, " OK ");
+		strcat(buffer, " TU ");
 		sendbuf();
 		break;
 	    } else if (x == '=' && strlen(hiscall) != 0) {
 		/** \todo check if unreachable code */
 		strcat(buffer, lastcall);
-		strcat(buffer, " OK ");
+		strcat(buffer, " TU ");
 		sendbuf();
 		break;
 	    }
@@ -204,8 +202,7 @@ char callinput(void)
 	    {
 		if ((ctcomp != 0) && (strlen(hiscall) > 2)) {
 		    if (trxmode == CWMODE || trxmode == DIGIMODE) {
-			strcat(buffer, message[2]);	/* F3 */
-			sendbuf();
+			sendmessage(message[2]);	/* F3 */
 
 		    } else
 			play_file(ph_message[2]);
@@ -222,21 +219,6 @@ char callinput(void)
 		break;
 	    }
 
-	case 153:		// down - start sending call if cw mode
-	case 32:		// space
-	    {
-		if (trxmode == CWMODE && contest == 1) {
-		    strcpy(buffer, hiscall);
-		    early_started = 1;
-		    sending_call = 1;
-		    sendbuf();
-		    sending_call = 0;
-		    strcpy(hiscall_sent, hiscall);
-		    printcall();
-		    x = 153;
-		} 
-		break;
-	    }
 	case 155:		/* left */
 	    {
 		if (*hiscall != '\0') {
@@ -255,20 +237,15 @@ char callinput(void)
 			    || (bandinx == 7)))
 			bandinx--;
 
-		    attron(COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+		    attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
 		    mvprintw(12, 0, band[bandinx]);
 		    i--;
-#ifdef HAVE_LIBHAMLIB
+
 		    if (trx_control == 1) {
 
 			outfreq = (int) (bandfrequency[bandinx] * 1000);
 		    }
-#else
-		    if (trx_control == 1 && rignumber >= 2000) {
 
-			outfreq = (int) (bandfrequency[bandinx] * 1000);
-		    }
-#endif
 		    send_bandswitch(bandinx);
 
 		}
@@ -290,23 +267,15 @@ char callinput(void)
 			    || (bandinx == 7)))
 			bandinx++;
 
-		    attron(COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+		    attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
 		    mvprintw(12, 0, band[bandinx]);
 
-#ifdef HAVE_LIBHAMLIB
-
 		    if (trx_control == 1) {
 			freq = bandfrequency[bandinx];
 
 			outfreq = (int) (bandfrequency[bandinx] * 1000);
 		    }
-#else
-		    if (trx_control == 1 && rignumber >= 2000) {
-			freq = bandfrequency[bandinx];
 
-			outfreq = (int) (bandfrequency[bandinx] * 1000);
-		    }
-#endif
 		    send_bandswitch(bandinx);
 
 		}
@@ -314,58 +283,37 @@ char callinput(void)
 	    }
 	case 247:		// Alt-w set weight
 	    {
-		strncpy(speedbuf, speedstr + (2 * keyspeed), 2);
-		speedbuf[2] = '\0';
-		nicebox(1, 1, 2, 11, "Cw");
-		attron(COLOR_PAIR(COLOR_WHITE) | A_STANDOUT);
-		mvprintw(2, 2, "Speed: %s  ", speedbuf);
-		if (weight < 0)
-		    mvprintw(3, 2, "Weight:%d ", weight);
-		else
-		    mvprintw(3, 2, "weight: %d  ", weight);
-		mvprintw(3, 10, "");
-		refreshp();
-		x = onechar();
+		char weightbuf[5] = "";
+		char *end;
 
-		if (x == '-') {
-		    mvprintw(3, 9, "%c", '-');
-		    refreshp();
-		    weightbuf[0] = x;
-		    x = onechar();
-		    if (x != 27) {
-			mvprintw(3, 10, "%c", (char) x);
-			refreshp();
-			weightbuf[1] = x;
-			weightbuf[2] = '\0';
-			x = onechar();
-		    }
-		    if (x != 27) {
-			mvprintw(3, 11, "%c", (char) x);
-			refreshp();
-			weightbuf[2] = x;
-			weightbuf[3] = '\0';
-		    }
-		} else {
-		    weightbuf[0] = x;
-		    weightbuf[1] = '\0';
-		    mvprintw(3, 10, "%c", (char) x);
-		    refreshp();
-		    x = onechar();
-		    if (x != 27) {
-			weightbuf[1] = x;
-			weightbuf[2] = '\0';
+		mvprintw(12, 29, "Wght: -50..50");
+
+		nicebox(1, 1, 2, 12, "Cw");
+		attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
+		mvprintw(2, 2, "Speed:   %2d ", GetCWSpeed());
+		mvprintw(3, 2, "Weight: %3d ", weight);
+		refreshp();
+
+		usleep(800000);
+		mvprintw(3, 10, "   ");
+
+		echo();
+		mvgetnstr(3, 10, weightbuf, 3);
+		noecho();
+
+		g_strchomp(weightbuf);
+
+		int tmp = strtol(weightbuf, &end, 10);
+
+		if ((weightbuf[0] != '\0') && (*end == '\0')) {
+		    /* successful conversion */
+
+		    if (tmp > -51 && tmp < 51) {
+			weight = tmp;
+			netkeyer(K_WEIGHT, weightbuf);
 		    }
 		}
-		x = -1;
-		weight = atoi(weightbuf);
-		if (weight > -51 && weight < 50) {
-		    netkeyer(K_WEIGHT, weightbuf);
-		}
-		attron(COLOR_PAIR(COLOR_WHITE) | A_STANDOUT);
-		mvprintw(1, 1, "             ");
-		mvprintw(2, 1, "             ");
-		mvprintw(3, 1, "             ");
-		mvprintw(4, 1, "             ");
+		clear_display();
 		printcall();
 
 		break;
@@ -375,41 +323,29 @@ char callinput(void)
 		if (ctcomp == 1) {
 		    while (x != 27)	//escape
 		    {
-			strncpy(speedbuf, speedstr + (2 * keyspeed), 2);
-			speedbuf[2] = '\0';
-			nicebox(1, 1, 2, 9, "Cw");
-			attron(COLOR_PAIR(COLOR_WHITE) | A_STANDOUT);
-			mvprintw(2, 2, "Speed: %s", speedbuf);
-			mvprintw(3, 2, "Weight: %d", weight);
+			nicebox(1, 1, 2, 12, "Cw");
+			attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
+			mvprintw(2, 2, "Speed:   %2d ", GetCWSpeed());
+			mvprintw(3, 2, "Weight: %3d ", weight);
 			printcall();
 			refreshp();
 
 			x = onechar();
 			if (x == 152) {
-			    keyspeed = speedup();
-			    strncpy(speedbuf, speedstr + (2 * keyspeed),
-				    2);
-			    speedbuf[2] = '\0';
-			    attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+			    speedup();
+			    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 
-			    mvprintw(0, 14, "%s", speedbuf);
+			    mvprintw(0, 14, "%2d", GetCWSpeed());
 
 			} else if (x == 153) {
-			    keyspeed = speeddown();
-			    strncpy(speedbuf, speedstr + (2 * keyspeed),
-				    2);
-			    speedbuf[2] = '\0';
-			    attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
-			    mvprintw(0, 14, "%s", speedbuf);
+			    speeddown();
+			    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
+			    mvprintw(0, 14, "%2d", GetCWSpeed());
 
 			} else
 			    x = 27;
 
-			attron(COLOR_PAIR(COLOR_WHITE) | A_STANDOUT);
-			mvprintw(1, 1, "           ");
-			mvprintw(2, 1, "           ");
-			mvprintw(3, 1, "           ");
-			mvprintw(4, 1, "           ");
+			clear_display();
 		    }
 		} else {	// trlog compatible, band switch
 		    if (bandinx >= 0 && *hiscall == '\0') {
@@ -424,17 +360,17 @@ char callinput(void)
 				|| (bandinx == 7)))
 			    bandinx--;
 
-			attron(COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+			attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
 			mvprintw(12, 0, band[bandinx]);
 			printcall();
 			i--;
-#ifdef HAVE_LIBHAMLIB
+
 			if (trx_control == 1) {
 
 			    outfreq =
 				(int) (bandfrequency[bandinx] * 1000);
 			}
-#endif
+
 			send_bandswitch(bandinx);
 
 		    }
@@ -452,18 +388,16 @@ char callinput(void)
 		    if (his_rst[1] <= 56) {
 
 			his_rst[1]++;
-			
+
 			no_rst ? : mvprintw(12, 44, his_rst);
 			mvprintw(12, 29, hiscall);
 		    }
 
 		} else {	// change cw speed
-		    keyspeed = speedup();
+		    speedup();
 
-		    strncpy(speedbuf, speedstr + (2 * keyspeed), 2);
-		    speedbuf[2] = '\0';
-		    attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
-		    mvprintw(0, 14, "%s", speedbuf);
+		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
+		    mvprintw(0, 14, "%2d", GetCWSpeed());
 		}
 
 		break;
@@ -473,7 +407,7 @@ char callinput(void)
 		if (cqdelay <= 60) {
 		    cqdelay++;
 
-		    attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 		    mvprintw(0, 19, "  ");
 		    mvprintw(0, 19, "%i", cqdelay);
 		}
@@ -494,12 +428,10 @@ char callinput(void)
 
 		} else {
 
-		    keyspeed = speeddown();
+		    speeddown();
 
-		    strncpy(speedbuf, speedstr + (2 * keyspeed), 2);
-		    speedbuf[2] = '\0';
-		    attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
-		    mvprintw(0, 14, "%s", speedbuf);
+		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
+		    mvprintw(0, 14, "%2d", GetCWSpeed());
 		}
 		break;
 	    }
@@ -507,7 +439,7 @@ char callinput(void)
 		if (cqdelay >= 4) {
 		    cqdelay--;
 
-		    attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 		    mvprintw(0, 19, "  ");
 		    mvprintw(0, 19, "%i", cqdelay);
 		}
@@ -531,8 +463,7 @@ char callinput(void)
 		searchlog(hiscall);
 
 		if (isdupe != 0) {
-		    strcat(buffer, message[6]);	/* as with F7 */
-		    sendbuf();
+		    sendmessage(message[6]);	/* as with F7 */
 		    cleanup();
 		    clear_display();
 		}
@@ -542,8 +473,7 @@ char callinput(void)
 	    {
 		if (ctcomp != 0) {
 		    if (trxmode == CWMODE || trxmode == DIGIMODE) {
-			strcat(buffer, message[1]);
-			sendbuf();
+			sendmessage(message[1]);
 
 		    } else
 			play_file(ph_message[1]);
@@ -557,7 +487,7 @@ char callinput(void)
 		hiscall[0] = '\0';
 		x = 0;
 		clear_display();
-		attron(COLOR_PAIR(7) | A_STANDOUT);
+		attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 
 		for (j = 13; j <= 23; j++) {
 		    mvprintw(j, 0, backgrnd_str);
@@ -580,11 +510,8 @@ char callinput(void)
 		    mvprintw(14, 68, "MEM: %7.1f", mem);
 		} else {
 		    freq = mem;
-#ifdef HAVE_LIBHAMLIB
+
 		    outfreq = (int) (mem * 1000);
-#else
-		    outfreq = (mem * 1000);
-#endif
 
 		    mem = 0.0;
 		    mvprintw(14, 68, "            ");
@@ -610,8 +537,7 @@ char callinput(void)
 
 	case 176 ... 186:
 	    {
-		strcat(buffer, message[x - 162]);	/* alt-0 to alt-9 */
-		sendbuf();
+		sendmessage(message[x - 162]);	/* alt-0 to alt-9 */
 
 		break;
 	    }
@@ -624,12 +550,12 @@ char callinput(void)
 			if (demode == SEND_DE)
 			    strcat(buffer, "DE ");
 			strcat(buffer, call);		/* S&P */
+			sendbuf();
 		    }
 		    else {
-			strcat(buffer, message[0]);	/* CQ */
+			sendmessage(message[0]);	/* CQ */
 		    }
 
-		    sendbuf();
 
 		    if (simulator != 0) {
 			simulator_mode = 1;
@@ -647,8 +573,7 @@ char callinput(void)
 	case 130 ... 138:			/* F2.. F10 */
 	    {
 		if (trxmode == CWMODE || trxmode == DIGIMODE) {
-		    strcat(buffer, message[x - 129]);	/* F2 */
-		    sendbuf();
+		    sendmessage(message[x - 129]);	/* F2 */
 
 		} else
 		    play_file(ph_message[x - 129]);
@@ -658,8 +583,8 @@ char callinput(void)
 	case 140:
 	    {
 		if (trxmode == CWMODE || trxmode == DIGIMODE) {
-		    strcat(buffer, message[10]);	/* F11 */
-		    sendbuf();
+		    sendmessage(message[10]);	/* F11 */
+
 		} else
 		    play_file(ph_message[10]);
 
@@ -673,8 +598,8 @@ char callinput(void)
 	    {
 		if (*hiscall != '\0') {
 		    getyx(stdscr, cury, curx);
-		    mvprintw(12, curx - 1, " ");
-		    mvprintw(12, curx - 1, "");
+		    mvprintw(cury, curx - 1, " ");
+		    mvprintw(cury, curx - 1, "");
 		    hiscall[strlen(hiscall) - 1] = '\0';
 
 		    if (atoi(hiscall) < 1800) {	/*  no frequency */
@@ -701,18 +626,12 @@ char callinput(void)
 		    showscore_flag = 1;
 		else {
 		    showscore_flag = 0;
-		    /** \todo drop display of scrore */
-		    attron(COLOR_PAIR(7) | A_STANDOUT);
+		    /** \todo drop display of score */
+		    attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 		    for (ii = 14; ii < 24; ii++)
 			mvprintw(ii, 0, backgrnd_str);
-		    refreshp();
 		}
-		break;
-	    }
-	case 142 ... 150:
-	    {
-		message_change(x);
-
+		clear_display();
 		break;
 	    }
 	case 235:
@@ -726,7 +645,7 @@ char callinput(void)
 		    cluster = CLUSTER;	// alt-A
 		    announcefilter = FILTER_ALL;
 		} else if (cluster == CLUSTER) {
-		    attron(COLOR_PAIR(7) | A_STANDOUT);
+		    attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 
 		    for (ii = 14; ii < 24; ii++)
 			mvprintw(ii, 0, backgrnd_str);
@@ -734,7 +653,7 @@ char callinput(void)
 
 		    cluster = MAP;
 		} else if (cluster == MAP) {
-		    attron(COLOR_PAIR(7) | A_STANDOUT);
+		    attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 
 		    for (ii = 14; ii < 24; ii++)
 			mvprintw(ii, 0, backgrnd_str);
@@ -759,17 +678,15 @@ char callinput(void)
 				|| (bandinx == 7)))
 			    bandinx++;
 
-			attron(COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+			attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
 			mvprintw(12, 0, band[bandinx]);
 
-#ifdef HAVE_LIBHAMLIB
-
 			if (trx_control == 1) {
 			    freq = bandfrequency[bandinx];
 			    outfreq =
 				(int) (bandfrequency[bandinx] * 1000);
 			}
-#endif
+
 			send_bandswitch(bandinx);
 
 		    }
@@ -789,12 +706,7 @@ char callinput(void)
 	    }
 	case 232:		// alt-H
 	    {
-		endwin();
-		rc=system("clear");
-		rc=system("less help.txt");
-		rc=system("clear");
-		set_term(mainscreen);
-		clear_display();
+		show_help();
 		break;
 	    }
 
@@ -823,7 +735,7 @@ char callinput(void)
 	    {
 		if (k_ptt == 0) {
 		    k_ptt = 1;
-		    attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 		    mvprintw(0, 2, "PTT on   ");
 		    mvprintw(12, 29, "");
 		    refreshp();
@@ -844,7 +756,7 @@ char callinput(void)
 		int count;
 		gchar *buff;
 
-		attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+		attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 		mvprintw(0, 2, "Tune     ");
 		mvprintw(12, 29, "");
 		refreshp();
@@ -900,6 +812,7 @@ char callinput(void)
 
 		    if (x == 'y' || x == 'Y') {
 			writeparas();
+			cleanup_telnet();
 			endwin();
 
 			puts("\n\nThanks for using TLF.. 73\n");
@@ -1028,7 +941,7 @@ char callinput(void)
 
 		    refreshp();
 		    getchar();
-		    attron(COLOR_PAIR(7) | A_STANDOUT);
+		    attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 		    for (t = 0; t <= 6; t++)
 			mvprintw(14 + t, 0,
 				 "                                                             ");
@@ -1050,38 +963,26 @@ char callinput(void)
 		instring[1] = '\0';
 		addch(x);
 		strcat(hiscall, instring);
-		if (cwstart != 0 && trxmode == CWMODE && contest == 1) {
-		    /* early start keying after 'cwstart' characters */
-		    if (strlen(hiscall) == cwstart) {
-			strcpy(buffer, hiscall);
-			early_started = 1;
-			sending_call = 1;
-			sendbuf();
-			sending_call = 0;
-			strcpy(hiscall_sent, hiscall);
+		if (cqmode == CQ && cwstart != 0 &&
+			trxmode == CWMODE && contest == 1) {
+		    /* early start keying after 'cwstart' characters but only
+		     * if input field contains at least one nondigit */
+		    if (strlen(hiscall) == cwstart && !plain_number(hiscall)) {
+			x = autosend();
 		    }
 		}
 	    }
 
-	    refreshp();
-
 	    if (atoi(hiscall) < 1800) {	/*  no frequency */
 
 		strncpy(dupecall, hiscall, 16);
 
 		y = getctydata(dupecall);
-
 		showinfo(y);
 
 		searchlog(hiscall);
-
-
-	    } else {
-		attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
-		mvprintw(24, 0,
-			 "                                                           ");
-		mvprintw(12, 29 + strlen(hiscall), "");
 	    }
+
 	    refreshp();
 
 	}
@@ -1090,7 +991,7 @@ char callinput(void)
 	    || x == 92)
 	    break;
 
-	if (trxmode == DIGIMODE && (keyerport == GMFSK 
+	if (trxmode == DIGIMODE && (keyerport == GMFSK
 		|| keyerport == MFJ1278_KEYER)) {
 	    show_rtty();
 	    refreshp();
@@ -1101,6 +1002,142 @@ char callinput(void)
     return (x);
 }
 
+/** check if string is plain number
+ *
+ * Check if string contains only digits
+ * \param str    the string to check
+ * \return true  if only digits inside
+ *         false at least one none digit
+ */
+int plain_number(char *str) {
+    int i;
+
+    for (i=0; i < strlen(str); i++) {
+	if (!isdigit(str[i])) {
+	    return false;
+	}
+    }
+
+    return true;
+}
+
+
+/** autosend function
+ *
+ * autosend allow an operator in RUN mode to just enter the call of the
+ * other station. TLF will start sending the call and switch automatically
+ * to sending the exchange when typing stops.
+ *  - starts after 2..5 characters
+ *  - shorter calls have to be finished with ENTER key
+ *  - as soon as autosend starts only alfanumerical keys are accepted
+ *  - no edit after input possible
+ *  - calculates expected time to send call from cw speed and
+ *  - switches to sending exchange after that time is reached
+ *
+ *  \return last typed key, ESC or \n
+ *          ESC - transmission has stopped
+ *          \n  - timeout or CR pressed -> send exchange
+ */
+int autosend()
+{
+    extern char buffer[];
+    extern int early_started;
+    extern int sending_call;
+    extern char hiscall_sent[];
+    extern char hiscall[];
+    extern char wkeyerbuffer[];
+
+    GTimer *timer;
+    double timeout, timeout_sent;
+    int x;
+    int char_sent;
+
+    strcpy(buffer, hiscall);
+    early_started = 1;
+    sending_call = 1;
+    sendbuf();
+    sending_call = 0;
+    strcpy(hiscall_sent, hiscall);
+
+    char_sent = 0; 			/* no char sent so far */
+    timeout_sent = (1.2 / GetCWSpeed()) * getCWdots(hiscall[char_sent]);
+
+    timer = g_timer_new();
+    timeout = (1.2 / GetCWSpeed()) * cw_message_length(hiscall);
+
+    x = -1;
+    while ((x != 27) && (x != '\n')) {
+	nodelay(stdscr, TRUE);
+	x = -1;
+	while ((x == -1) && (g_timer_elapsed(timer, NULL) < timeout)) {
+
+	    highlightCall(char_sent + 1);
+
+	    usleep(10000);
+
+	    if (g_timer_elapsed(timer, NULL) > timeout_sent) {
+		/* one char sent - display and set new timeout */
+		char_sent ++;
+		timeout_sent +=
+		    (1.2 / GetCWSpeed()) * getCWdots(hiscall[char_sent]);
+
+	    }
+
+	    /* make sure that the wrefresh() inside getch() shows the cursor
+	     * in the input field */
+	    wmove(stdscr, 12, 29 + strlen(hiscall));
+	    x = onechar();
+
+	}
+	nodelay(stdscr, FALSE);
+
+	if (x == -1) { 		/* timeout */
+	    x = '\n';
+	    continue;
+	}
+
+	if (x == 27) {
+	    stoptx();
+	    *hiscall_sent = '\0';
+	    early_started = 0;
+	    continue;
+	}
+
+	/* convert to upper case */
+	if (x >= 'a' && x <= 'z')
+	    x = x - 32;
+
+	int len = strlen(hiscall);
+	if (len < 13 && x >= '/' && x <= 'Z') {
+	    char append[2];
+
+	    /* insert into hiscall */
+	    hiscall[len] = x;
+	    hiscall[len+1] = '\0';
+
+	    /* display it  */
+	    printcall();
+
+	    /* send it to cw */
+	    append[0] = x;
+	    append[1] = '\0';
+	    strcat(wkeyerbuffer, append);
+	    sendbuf();
+
+	    /* add char length to timeout */
+	    timeout += (1.2 / GetCWSpeed()) * getCWdots((char) x);
+
+	    len = strlen(hiscall_sent);
+	    hiscall_sent[len] = x;
+	    hiscall_sent[len+1] = '\0';
+	}
+    }
+
+    g_timer_destroy(timer);
+    return x;
+}
+
+
 int play_file(char *audiofile)
 {
 
@@ -1117,7 +1154,7 @@ int play_file(char *audiofile)
     } else {
 	close(fd);
 	if (access("./play_vk", X_OK) == 0 ) {
-	   sprintf( playcommand, "./play_vk %s", audiofile); 
+	   sprintf( playcommand, "./play_vk %s", audiofile);
 	}
 	else {
 	   sprintf( playcommand, "play_vk %s", audiofile);
