@@ -2,6 +2,7 @@
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003-2004-2005 Rein Couperus <pa0r@eudx.org>
  *               2011-2012                Thomas Beierlein <tb@forth-ev.de>
+ *               2013                     Ervin Hegedus <airween@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -10,12 +11,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 	/* ------------------------------------------------------------
@@ -27,13 +28,21 @@
 #include "recall_exchange.h"
 #include "addspot.h"
 #include "logit.h"
+#include "cw_utils.h"
 #include <glib.h>
+#include "locator2longlat.h"
 
 #define MULTS_POSSIBLE(n) ((char *)g_ptr_array_index(mults_possible, n))
 #define LEN(array) (sizeof(array) / sizeof(array[0]))
 
 int play_file(char *audiofile);
 
+
+int checkexchange (int x);
+int getlastpattern (char *checkstring);
+char *getgrid (char *comment);
+void exchange_edit (void);
+
 int getexchange(void)
 {
     extern int contest;
@@ -41,9 +50,8 @@ int getexchange(void)
     extern char cqzone[];
     extern char ituzone[];
     extern char my_rst[];
-    extern char speedstr[];
     extern int change_rst;
-    extern char message[15][80];
+    extern char message[][80];
     extern char ph_message[14][80];
     extern char hiscall[];
     extern char buffer[];
@@ -51,6 +59,7 @@ int getexchange(void)
     extern int cqww;
     extern int wpx;
     extern int pacc_pa_flg;
+    extern int stewperry_flg;
     extern int arrldx_usa;
     extern int arrl_fd;
     extern int exchange_serial;
@@ -85,8 +94,6 @@ int getexchange(void)
     char commentbuf[40] = "";
     int retval;
     char *gridmult = "";
-    int keyspeed = 30;
-    char speedbuf[3] = "";
 
     instring[1] = '\0';
 
@@ -116,8 +123,17 @@ int getexchange(void)
 	strcpy(comment, continent);
     }
 
+    if (stewperry_flg == 1) {
+	retval = recall_exchange();
+    }
+
+    /* parse input and modify exchange field accordingly */
+
     commentfield = 1;
-    for (i = strlen(comment); i < 26; i++) {
+
+    i = strlen(comment);
+
+    while (1) {
 
 	refresh_comment();
 
@@ -155,9 +171,9 @@ int getexchange(void)
 
 	case 127:					/* erase */
 	    {
-		if (strlen(comment) >= 1) {
+		if (i >= 1) {
 		    comment[strlen(comment) - 1] = '\0';
-		    i -= 2;
+		    i -= 1;
 		}
 		break;
 	    }
@@ -180,8 +196,7 @@ int getexchange(void)
 	    {
 		if (ctcomp != 0) {
 		    if (trxmode == CWMODE || trxmode == DIGIMODE) {
-			strcat(buffer, message[1]);
-			sendbuf();
+			sendmessage(message[1]);
 
 		    } else
 			play_file(ph_message[1]);
@@ -194,8 +209,7 @@ int getexchange(void)
 	    {
 		if ((ctcomp != 0) && (strlen(hiscall) > 2)) {
 		    if (trxmode == CWMODE || trxmode == DIGIMODE) {
-			strcat(buffer, message[2]);	/* F3 */
-			sendbuf();
+			sendmessage(message[2]);	/* F3 */
 
 		    } else
 			play_file(ph_message[2]);
@@ -219,8 +233,8 @@ int getexchange(void)
 	case 130 ... 138:
 	    {
 		if (trxmode == CWMODE || trxmode == DIGIMODE) {
-		    strcat(buffer, message[x - 129]);	/* F2..F10 */
-		    sendbuf();
+		    sendmessage(message[x - 129]);	/* F2..F10 */
+
 		} else
 		    play_file(ph_message[x - 129]);
 
@@ -229,8 +243,8 @@ int getexchange(void)
 	case 140:
             {
                 if (trxmode == CWMODE || trxmode == DIGIMODE) {
-                    strcat(buffer, message[10]);        /* F11 */
-                    sendbuf();
+                    sendmessage(message[10]);        /* F11 */
+
                 } else
                     play_file(ph_message[10]);
 
@@ -238,12 +252,18 @@ int getexchange(void)
             }
 	case 176 ... 186:
 	    {
-		strcat(buffer, message[x - 162]);	/* alt-0 to alt-9 */
-		sendbuf();
+		sendmessage(message[x - 162]);	/* alt-0 to alt-9 */
 
 		break;
 	    }
 
+	case 155:		/* edit exchange field */
+	    {
+		if (*comment != '\0')
+		    exchange_edit();
+		break;
+	    }
+
 	case 156:		/* change MY RST */
 	    {
 		if (change_rst == 1) {
@@ -253,12 +273,10 @@ int getexchange(void)
 			no_rst ? : mvprintw(12, 49, my_rst);
 		    }
 		} else {	/* speed up */
-		    keyspeed = speedup();
-		    strncpy(speedbuf, speedstr + (2 * keyspeed), 2);
-		    speedbuf[2] = '\0';
+		    speedup();
 
-		    attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
-		    mvprintw(0, 14, "%s", speedbuf);
+                    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
+		    mvprintw(0, 14, "%2d", GetCWSpeed());
 		}
 		break;
 
@@ -273,17 +291,16 @@ int getexchange(void)
 			no_rst ? : mvprintw(12, 49, my_rst);
 		    }
 		} else {
-		    keyspeed = speeddown();
-		    strncpy(speedbuf, speedstr + (2 * keyspeed), 2);
-		    speedbuf[2] = '\0';
+		    speeddown();
 
-		    attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
-		    mvprintw(0, 14, "%s", speedbuf);
+                    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
+		    mvprintw(0, 14, "%2d", GetCWSpeed());
 		}
 		break;
 
 	    }
 	case 44:		// , keyer
+	case 11:		// ctrl-k
 	    {
 		mvprintw(5, 0, "");
 		keyer();
@@ -291,7 +308,7 @@ int getexchange(void)
 		break;
 	    }
 	case '\n':
-	    {			/* log QSO immediately if CT compatible 
+	    {			/* log QSO immediately if CT compatible
 				 * or not in contest */
 		if ((ctcomp == 1) || (contest != 1))
 		    x = 92;
@@ -312,16 +329,17 @@ int getexchange(void)
 		    show_rtty();
 		    mvprintw(12, 54, comment);
 		}
+		i++;
 		refreshp();
 	    }
-	} else
-	    i--;
+	}
 
 	if ((serial_section_mult == 1) ||
 	    (dx_arrlsections == 1) ||
 	    (sectn_mult == 1) ||
 	    (arrlss == 1) ||
-	    (cqww == 1)) {
+	    (cqww == 1) ||
+	    (stewperry_flg == 1)) {
 
 	    x = checkexchange(x);
 	}
@@ -426,6 +444,14 @@ int getexchange(void)
 		break;
 //                              x = 0; //##debug
 
+	    } else if (stewperry_flg == 1) {
+		if (check_qra(comment) > 0) {
+		    mvprintw(13, 54, "locator?");
+		    mvprintw(12, 54, comment);
+		    break;
+		}
+		refreshp();
+		break;
 	    } else
 		break;
 
@@ -439,7 +465,8 @@ int getexchange(void)
     return (x);
 }
 
-/*  --------------------------------------------------------------------------*/
+
+/* ------------------------------------------------------------------------ */
 
 char cmpattern[32] = "                               ";	// global
 char ssexchange[30] = "";
@@ -448,7 +475,8 @@ char callupdate[7];
 int call_update = 0;
 char zone_export[3] = "  ";
 char zone_fix[3] = "";
-/*  --------------------------------------------------------------------------*/
+
+/* ------------------------------------------------------------------------ */
 
 int checkexchange(int x)
 {
@@ -458,6 +486,7 @@ int checkexchange(int x)
     extern GPtrArray *mults_possible;
     extern int cqww;
     extern int arrlss;
+    extern int stewperry_flg;
     extern char section[];
     extern char callupdate[];
     extern char hiscall[];
@@ -474,7 +503,7 @@ int checkexchange(int x)
     char checksection[30];
     char zone[4] = "";
 
-/* field of allowed pattern sequences 
+/* field of allowed pattern sequences
  *
  * The characters have the following meaning:
  * u - undefined (left or right delimiter)
@@ -482,7 +511,7 @@ int checkexchange(int x)
  * a - ascii character
  * f - a figure / digit
  *
- * e.g. faf means a character between two digits 
+ * e.g. faf means a character between two digits
  */
     char serpats[8][8] = {
 	"bfb",
@@ -662,7 +691,7 @@ int checkexchange(int x)
 	    hr = getlastpattern(serpats[ii]);
 
 	    if (hr > 0)
-			snprintf(serial, sizeof(serial), "%4d", 
+			snprintf(serial, sizeof(serial), "%4d",
 				atoi(comment + hr - 1));
 
 	    if (ii == 5 && hr > 0) {
@@ -671,7 +700,7 @@ int checkexchange(int x)
 	    }
 
 	}
-	
+
 	// get precedent
 
 	if (((comment[0] == 'A')
@@ -825,13 +854,13 @@ int checkexchange(int x)
 		hr = getlastpattern(serpats[ii]);
 
 		if (hr > 0)
-		    snprintf(serial, sizeof(serial), "%4d", 
+		    snprintf(serial, sizeof(serial), "%4d",
 			    atoi(comment + hr - 1));
 
 		if (ii == 5 && hr > 0) {
-		    snprintf(serial, sizeof(serial), "%4d", 
+		    snprintf(serial, sizeof(serial), "%4d",
 			    atoi(comment + hr - 1));
-		    snprintf(check, sizeof(check), "%2d", 
+		    snprintf(check, sizeof(check), "%2d",
 			    atoi(comment + hr + 2));
 		}
 
@@ -957,7 +986,7 @@ int checkexchange(int x)
 
     }
     OnLowerSearchPanel(32, "   ");
-    OnLowerSearchPanel(32, section);	/* show section on lower frame of 
+    OnLowerSearchPanel(32, section);	/* show section on lower frame of
 					   Worked window */
     ssexchange[0] = '\0';
 
@@ -976,7 +1005,7 @@ int checkexchange(int x)
 }
 
 
-/*  --------------------------------------------------------------------------*/
+/* ------------------------------------------------------------------------ */
 
 /** search checkstring in cmpattern
  *
@@ -1008,7 +1037,9 @@ int getlastpattern(char *checkstring)
 
 }
 
-/*  --------------------------------------------------------------------------*/
+/* ------------------------------------------------------------------------
+ * return a pointer to the start of grid locator
+ */
 
 char *getgrid(char *comment)
 {
@@ -1017,6 +1048,7 @@ char *getgrid(char *comment)
     int multposition = 0;
     int i = 0;
 
+    /* search for first letter, that should be the start of the Grid locator*/
     for (i = 0; i < strlen(comment); i++) {
 	if (comment[i] > 64 && comment[i] < 91) {
 	    multposition = i;
@@ -1027,3 +1059,94 @@ char *getgrid(char *comment)
 
     return (gridmult);
 }
+
+/* ------------------------------------------------------------------------ */
+/** Edit exchange field
+ */
+
+void exchange_edit (void)
+{
+    extern char comment[];
+
+    int l, b;
+    int i = 0, j;
+    char comment2[27];
+
+    l = strlen(comment);
+    b = l - 1;
+
+    while ((i != 27) && (b <= strlen(comment))) {
+	attroff(A_STANDOUT);
+	attron(COLOR_PAIR(C_HEADER));
+
+	mvprintw(12, 54, "                          ");
+	mvprintw(12, 54, comment);
+	mvprintw(12, 54 + b, "");
+
+	i = onechar();
+
+	if (i == 1) {		// ctrl-A, Home
+
+	    b = 0;
+
+	} else if (i == 5) {	// ctrl-E, End
+
+	    b = strlen(comment) - 1;
+
+	} else if (i == 155) {	// left
+
+	    if (b > 0)
+		b--;
+
+	} else if (i == 154) {	// right
+
+	    if (b < strlen(comment) - 1) {
+		b++;
+	    } else
+		break;		/* stop edit */
+
+	} else if (i == 161) {	/* delete */
+
+	    l = strlen(comment);
+
+	    for (j = b; j <= l; j++) {
+		comment[j] = comment[j + 1];	/* move to left incl.\0 */
+	    }
+
+	} else if (i == 127) {	/* backspace */
+
+	    if (b > 0) {
+		b--;
+
+		l = strlen(comment);
+
+		for (j = b; j <= l; j++) {
+		    comment[j] = comment[j + 1];
+		}
+	    }
+	} else if (i != 27) {
+
+	    if ((i >= 'a') && (i <= 'z'))
+		i = i - 32;
+
+	    if ((i >= ' ') && (i <= 'Z')) {
+
+		if (strlen(comment) <= 24) {
+		    /* copy including trailing \0 */
+		    strncpy(comment2, comment + b, strlen(comment) - (b - 1));
+
+		    comment[b] = i;
+		    comment[b + 1] = '\0';
+		    strcat(comment, comment2);
+
+		    b++;
+		}
+
+	    } else if (i != 0)
+		i = 27;
+	}
+    }
+
+    attron(A_STANDOUT);
+    refresh_comment();
+}
