@@ -2,6 +2,7 @@
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0r@eudxf.org>
  *                    2010-2011 Thomas Beierlein <tb@forth-ev.de>
+ *                    2013      Ervin Hegedus <airween@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -10,20 +11,19 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#define NDEBUG
-#define NEWCODE = 1
 
 #include "tlf.h"
 #include "globalvars.h"
 #include "main.h"
 #include "searchlog.h"
+#include "cw_utils.h"
 #include <glib.h>
 #include <panel.h>
 #include <pthread.h>
@@ -53,7 +53,7 @@ int tlfcolors[8][2] = { {COLOR_BLACK, COLOR_WHITE},
 {COLOR_WHITE, COLOR_RED},
 {COLOR_CYAN, COLOR_WHITE},
 {COLOR_WHITE, COLOR_BLACK},
-{COLOR_MAGENTA, COLOR_WHITE},
+{COLOR_WHITE, COLOR_MAGENTA},
 {COLOR_BLUE, COLOR_YELLOW},
 {COLOR_WHITE, COLOR_BLACK}
 };
@@ -65,8 +65,10 @@ int tune_val = 0;
 int use_bandoutput = 0;
 int no_arrows = 0;
 int bandindexarray[10] = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 };
-int cqww = 0;
 int cqwwm2 = 0;
+
+/* predefined contests */
+int cqww = 0;
 int wpx = 0;
 int dxped = 0;
 int sprint = 0;
@@ -74,6 +76,9 @@ int arrldx_usa = 0;
 int arrl_fd = 0;
 int arrlss = 0;
 int pacc_pa_flg = 0;
+int stewperry_flg = 0;
+int focm = 0;
+
 int universal = 0;
 int addcallarea;
 int pfxmult = 0;
@@ -83,14 +88,12 @@ int other_flg;
 int one_point = 0;
 int two_point = 0;
 int three_point = 0;
-int two_eu_three_dx_points = 0;
 int ssbpoints;
 int cwpoints;
 int lowband_point_mult = 0;
 int sc_sidetone;
 char sc_volume[4] = "";
   /* LZ3NY mods */
-char contest_name[50];
 int countrylist_points = -1;
 int my_country_points = -1;
 int my_cont_points = -1;
@@ -108,7 +111,7 @@ int exchange_serial = 0;
 int wysiwyg_once = 0;
 int wysiwyg_multi = 0;
 int country_mult = 0;
-int fixedmult = 0;
+float fixedmult = 0.0;
 int sectn_mult = 0;
 int dx_arrlsections = 0;
 int serial_section_mult = 0;
@@ -124,6 +127,7 @@ int noautocq = 0;
 int emptydir = 0;
 int verbose = 0;
 int no_rst = 0;			/* 1 - do not use RS/RST */
+char myqra[7] = "";
 
 int pacc_qsos[10][10];
 int ve_cty;
@@ -137,9 +141,7 @@ int vk_cty;
 int zs_cty;
 int ua9_cty;
 
-char tlfversion[80] = "";
-char testbuffer[120] = "";
-char multsfile[80] = "";	/* name of file with a list of allowed 
+char multsfile[80] = "";	/* name of file with a list of allowed
 				   multipliers */
 char exchange_list[40] = "";
 int timeoffset = 0;
@@ -165,9 +167,10 @@ char sp_return[80] = " \n";
 char cq_return[80] = " \n";
 char whichcontest[40] = "qso";
 int defer_store = 0;
-char buffer[162];
+extern char buffer[];
 char call[20];
 char logfile[120] = "general.log";
+char *cabrillo = NULL;		/*< Name of the cabrillo format definition */
 char synclogfile[120];
 char markerfile[120] = "";
 int xplanet = 0;
@@ -189,7 +192,6 @@ int sending_call = 0;
 int early_started = 0;			/**< 1 if sending call started early,
 					   strlen(hiscall)>cwstart or 'space' */
 char lastcall[20];
-char lastcomment[40];
 char qsonrstr[5] = "0001";
 char band[9][4] =
     { "160", " 80", " 40", " 30", " 20", " 17", " 15", " 12", " 10" };
@@ -208,8 +210,7 @@ int totalzones = 0;
 int secs = 0;
 int countrynr;
 int mycountrynr = 215;
-int points = 0;
-int total = 0;
+int total = 0; 		/**< total number of qso points */
 int band_score[9];
 int dupe = 0;
 int callfound = 0;
@@ -226,15 +227,13 @@ char sc_device[40] = "/dev/dsp";
 
 /*-------------------------------------keyer------------------------------*/
 int keyerport = NO_KEYER;
-int speed = 10;
 int txdelay = 0;
 int weight = 0;
 char weightbuf[4];
-char speedstr[50] = CW_SPEEDS;
 char tonestr[5] = "600";
 int cqdelay = 8;
 char wkeyerbuffer[400];
-int keyspeed = 5;
+int bufloc = 0;
 int cfd;			/* cwkeyer file descriptor */
 int data_ready = 0;
 char keyer_device[10] = "";	// ttyS0, ttyS1, lp0-2
@@ -249,8 +248,8 @@ int commentfield = 0;		/* 1 if we are in comment/excahnge input */
 /*-------------------------------------packet-------------------------------*/
 char spot_ptr[MAX_SPOTS][82];		/* Array of cluster spot lines */
 int spotarray[MAX_SPOTS];		/* Array of indices into spot_ptr */
+char lastwwv[120] = "";
 int ptr;				/* Anzahl Lines in ispot_ptr array */
-long int *wwv_ptr;
 int packetinterface = 0;
 int fdSertnc = 0;
 int fdFIFO = 0;
@@ -265,22 +264,18 @@ char clusterlogin[80] = "";
 #ifdef HAVE_LIBHAMLIB
 rig_model_t myrig_model = 351;
 RIG *my_rig;			/* handle to rig (instance) */
-freq_t rigfreq;			/* input frequency  */
 freq_t outfreq;			/* output  to rig */
 rmode_t rmode;			/* radio mode of operation */
 pbwidth_t width;
 vfo_t vfo;			/* vfo selection */
 port_t myport;
 #else
-float rigfreq;			/* input frequency  */
 int outfreq;			/* output  to rig */
 #endif
 int ssb_bandwidth = 3000;
 int cw_bandwidth = 0;
 int serial_rate = 2400;
-int rig_port = 0;
 char rigportname[40];
-int native_rig_fd = 0;
 int rignumber = 0;
 int rig_comm_error = 0;
 int rig_comm_success = 0;
@@ -289,12 +284,12 @@ int rig_comm_success = 0;
 int simulator = 0;
 int simulator_mode = 0;
 int simulator_seed = 8327;
-long system_secs;
+int system_secs;
 char tonecpy[5];
 char simulator_tone[5];
 
 /*-------------------------------the log lines-----------------------------*/
-char qsos[MAX_QSOS][82];
+char qsos[MAX_QSOS][LOGLINELEN+1];
 int nr_qsos = 0;
 
 /*------------------------------dupe array---------------------------------*/
@@ -333,16 +328,13 @@ int shownewmult = -1;
 int minute_timer = 0;
 
 int bandinx = BANDINDEX_40;	/* start with 40m */
-int qsonum = 1;
-int bufloc = 0;
+int qsonum = 1;			/* nr of next QSO */
 int ymax, xmax;			/* screen size */
-char lastwwv[120] = "";
 int nroflines;
 
 pid_t pid;
 struct tm *time_ptr;
 
-char qrg_string[8];
 float freq;
 float mem;
 int logfrequency = 0;
@@ -352,13 +344,14 @@ int showfreq = 0;
 float bandfrequency[9] =
     { 1830.0, 3525.0, 7010.0, 10105.0, 14025.0, 18070.0, 21025.0, 24900.0,
 28025.0 };
-char spot_target[8][40];
 
 char headerline[81] =
     "   1=CQ  2=DE  3=RST 4=73  5=HIS  6=MY  7=B4   8=AGN  9=?  \n";
 char backgrnd_str[81] =
     "                                                                                ";
 
+char logline_edit[5][LOGLINELEN+1];
+
 char terminal1[88] = "";
 char terminal2[88] = "";
 char terminal3[88] = "";
@@ -371,10 +364,6 @@ char C_QTH_Long[8] = "-5";
 char C_DEST_Lat[7] = "51";
 char C_DEST_Long[8] = "1";
 
-double yt = -4.9;		/* for muf calculation */
-double xt = 52.4;
-double yr = 5.0;
-double xr = 50.0;
 double r = 50;
 int m = 1;
 char hiscountry[40];
@@ -414,6 +403,7 @@ int main(int argc, char *argv[])
     int ret;
     int retval;
     char keyerbuff[3];
+    char tlfversion[80] = "";
     int status;
 
     while ((argc > 1) && (argv[1][0] == '-')) {
@@ -423,7 +413,7 @@ int main(int argc, char *argv[])
 	    if (strlen(argv[1] + 2) > 0) {
 		if ((*(argv[1] + 2) == '~') && (*(argv[1] + 3) == '/')) {
 		    /* tilde expansion */
-		    config_file = g_strconcat( g_get_home_dir(), 
+		    config_file = g_strconcat( g_get_home_dir(),
 			    argv[1] + 3, NULL);
 		}
 	    	else {
@@ -463,7 +453,6 @@ int main(int argc, char *argv[])
     }
 
     buffer[0] = '\0';
-    buffer[79] = '\0';
     bufloc = 0;
 
     strcat(logline0, backgrnd_str);
@@ -505,6 +494,21 @@ int main(int argc, char *argv[])
 				   for refreshp() to work */
 
     getmaxyx(stdscr, ymax, xmax);
+    if ((ymax < 25) || (xmax < 80)) {
+	char c;
+
+	showmsg( "!! TLF needs at least 25 lines and 80 columns !!");
+	showmsg( "   Continue anyway? Y/(N)" );
+	c = toupper( getch() );
+	if (c != 'Y') {
+	    showmsg( "73 es cuagn" );
+	    sleep(1);
+	    endwin();
+	    exit(1);
+	}
+	showmsg("");
+    }
+
     noecho();
     crmode();
 
@@ -522,15 +526,6 @@ int main(int argc, char *argv[])
 	    sleep(5);
 	    exit(EXIT_FAILURE);
 	}
-	// use linux console colours
-	init_pair(COLOR_BLACK, tlfcolors[0][0], tlfcolors[0][1]);
-	init_pair(COLOR_GREEN, tlfcolors[1][0], tlfcolors[1][1]);
-	init_pair(COLOR_RED, tlfcolors[2][0], tlfcolors[2][1]);
-	init_pair(COLOR_CYAN, tlfcolors[3][0], tlfcolors[3][1]);
-	init_pair(COLOR_WHITE, tlfcolors[4][0], tlfcolors[4][1]);
-	init_pair(COLOR_MAGENTA, tlfcolors[5][0], tlfcolors[5][1]);
-	init_pair(COLOR_BLUE, tlfcolors[6][0], tlfcolors[6][1]);
-	init_pair(COLOR_YELLOW, tlfcolors[7][0], tlfcolors[7][1]);
 
 	sprintf(tlfversion,
 		"        Welcome to tlf-%s by PA0R!!" , VERSION);
@@ -545,7 +540,7 @@ int main(int argc, char *argv[])
 	status = read_logcfg(); /* read the configuration file */
 	status |= read_rules();	/* read the additional contest rules in "rules/contestname"  LZ3NY */
 
-	if (status != PARSE_OK) { 
+	if (status != PARSE_OK) {
 	    showmsg( "Problems in logcfg.dat or rule file detected! Continue Y/(N)?");
 	    if (toupper( getchar() ) != 'Y') {
 		endwin();
@@ -553,7 +548,13 @@ int main(int argc, char *argv[])
 	    }
 	}
 
-	checklogfile();		/* make sure logfile is there */
+	/* make sure logfile is there and has the right format */
+	if (checklogfile_new(logfile) != 0) {
+	    showmsg( "Giving up" );
+	    sleep(2);
+	    endwin();
+	    exit(1);
+	}
 
 //              if (strlen(synclogfile) > 0)
 //                      synclog(synclogfile);
@@ -567,34 +568,30 @@ int main(int argc, char *argv[])
 	if (use_rxvt == 1) {	// use rxvt colours
 	    init_pair(COLOR_BLACK, COLOR_BLACK, COLOR_RED);
 	    if (use_xterm == 1) {
-		init_pair(COLOR_GREEN, COLOR_GREEN, COLOR_BLUE);
+		init_pair(C_HEADER, COLOR_GREEN, COLOR_BLUE);
 		init_pair(COLOR_RED, COLOR_WHITE, 8);
-		init_pair(COLOR_CYAN, COLOR_CYAN, COLOR_MAGENTA);
+		init_pair(C_WINDOW, COLOR_CYAN, COLOR_MAGENTA);
+		init_pair(C_DUPE, COLOR_WHITE, COLOR_MAGENTA);
+		init_pair(C_INPUT, COLOR_BLUE, COLOR_WHITE);
 	    } else {
-		init_pair(COLOR_GREEN, COLOR_GREEN, COLOR_YELLOW);
+		init_pair(C_HEADER, COLOR_GREEN, COLOR_YELLOW);
 		init_pair(COLOR_RED, COLOR_WHITE, COLOR_RED);
-		init_pair(COLOR_CYAN, COLOR_CYAN, COLOR_RED);
+		init_pair(C_WINDOW, COLOR_CYAN, COLOR_RED);
+		init_pair(C_DUPE, COLOR_RED, COLOR_MAGENTA);
+		init_pair(C_INPUT, COLOR_BLUE, COLOR_YELLOW);
 	    }
-	    init_pair(COLOR_WHITE, COLOR_WHITE, COLOR_BLACK);
-	    if (use_xterm == 1) {
-		init_pair(COLOR_MAGENTA, COLOR_MAGENTA, COLOR_WHITE);
-		init_pair(COLOR_BLUE, COLOR_BLUE, COLOR_WHITE);
-	    } else {
-		init_pair(COLOR_MAGENTA, COLOR_MAGENTA, COLOR_RED);
-		init_pair(COLOR_BLUE, COLOR_BLUE, COLOR_YELLOW);
-	    }
-	    init_pair(COLOR_YELLOW, COLOR_CYAN, COLOR_YELLOW);
+	    init_pair(C_LOG, COLOR_WHITE, COLOR_BLACK);
+	    init_pair(C_BORDER, COLOR_CYAN, COLOR_YELLOW);
 	} else {
-	    // use linux console colours redefined....
-	    init_pair(COLOR_BLACK, tlfcolors[0][0], tlfcolors[0][1]);
-	    init_pair(COLOR_GREEN, tlfcolors[1][0], tlfcolors[1][1]);
-	    init_pair(COLOR_RED, tlfcolors[2][0], tlfcolors[2][1]);
-	    init_pair(COLOR_CYAN, tlfcolors[3][0], tlfcolors[3][1]);
-	    init_pair(COLOR_WHITE, tlfcolors[4][0], tlfcolors[4][1]);
-	    init_pair(COLOR_MAGENTA, tlfcolors[5][0], tlfcolors[5][1]);
-	    init_pair(COLOR_BLUE, tlfcolors[6][0], tlfcolors[6][1]);
-	    init_pair(COLOR_YELLOW, tlfcolors[7][0], tlfcolors[7][1]);
-
+	    // use linux console colours
+	    init_pair(COLOR_BLACK, tlfcolors[0][0], tlfcolors[0][1]); // b/w
+	    init_pair(C_HEADER, tlfcolors[1][0], tlfcolors[1][1]);    // Gn/Ye
+	    init_pair(COLOR_RED, tlfcolors[2][0], tlfcolors[2][1]);   // W/R
+	    init_pair(C_WINDOW, tlfcolors[3][0], tlfcolors[3][1]);    // Cy/W
+	    init_pair(C_LOG, tlfcolors[4][0], tlfcolors[4][1]);       // W/B
+	    init_pair(C_DUPE, tlfcolors[5][0], tlfcolors[5][1]);      // W/Mag
+	    init_pair(C_INPUT, tlfcolors[6][0], tlfcolors[6][1]);     // Bl/Y
+	    init_pair(C_BORDER, tlfcolors[7][0], tlfcolors[7][1]);    // W/B
 	}
 
 	mults_possible = g_ptr_array_new();
@@ -628,7 +625,7 @@ int main(int argc, char *argv[])
 
 #ifdef HAVE_LIBHAMLIB		// Code for hamlib interface
 
-	showmsg("HAMLIB defined");
+	showmsg("HAMLIB compiled in");
 
 	if (trx_control != 0) {
 
@@ -637,22 +634,27 @@ int main(int argc, char *argv[])
 
 	    showmsg("Trying to start rig ctrl");
 
-	    /** \todo fix exclusion of newer hamlib models */
-	    if ((int) myrig_model > 1999)
-		init_native_rig();
-	    else
-		init_tlf_rig();
+	    status = init_tlf_rig();
+
+	    if (status  != 0) {
+		showmsg( "Continue without rig control Y/(N)?");
+		if (toupper( getchar() ) != 'Y') {
+		    endwin();
+		    exit(1);
+		}
+		trx_control = 0;
+		showmsg( "Disabling rig control!");
+		sleep(1);
+	    }
 	}
 #else
-	if (trx_control != 0) {
-//                      trx_control = 0;
-	    showmsg("No Hamlib library, using native driver");
-	    shownr("Rignumber is", rignumber);
-	    shownr("Rig speed is", serial_rate);
-	    init_native_rig();
-	    sleep(1);
-	}
-#endif				// end code for hamlib interface
+	showmsg("No Hamlib compiled in!");
+
+	trx_control = 0;
+	showmsg( "Disabling rig control!");
+	sleep(1);
+#endif				/* HAVE_LIBHAMLIB */
+
 
 	if (keyerport == NET_KEYER) {
 	    showmsg("Keyer is cwdaemon");
@@ -709,13 +711,11 @@ int main(int argc, char *argv[])
 
 		sprintf(weightbuf, "%d", weight);
 
-		strncpy(keyerbuff, speedstr + (speed * 2), 2);
-		keyerbuff[2] = '\0';
-
 		write_tone();
 
+		snprintf(keyerbuff, 3, "%2d", GetCWSpeed());
 		netkeyer(K_SPEED, keyerbuff);		// set speed
-	
+
 		netkeyer(K_WEIGHT, weightbuf);		// set weight
 
 		if (*keyer_device != '\0')
@@ -743,9 +743,9 @@ int main(int argc, char *argv[])
 
 	clear_display();	/* tidy up the display */
 
-	qrb();
+	qrb_();
 
-	attron(COLOR_PAIR(7) | A_STANDOUT);
+	attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 
 	for (j = 13; j <= 23; j++) {	/* wipe lower window */
 	    mvprintw(j, 0, backgrnd_str);
@@ -754,7 +754,7 @@ int main(int argc, char *argv[])
 	bm_init();			/* initialize bandmap */
 
 	/* Create the first thread */
-	ret = pthread_create(&thrd1, NULL, (void *) logit, NULL);
+	ret = pthread_create(&thrd1, NULL, logit, NULL);
 	if (ret) {
 	    perror("pthread_create: logit");
 	    endwin();
@@ -762,9 +762,7 @@ int main(int argc, char *argv[])
 	}
 
 	/* Create the second thread */
-	ret =
-	    pthread_create(&thrd2, NULL, (void *) background_process,
-			   NULL);
+	ret = pthread_create(&thrd2, NULL, background_process, NULL);
 	if (ret) {
 	    perror("pthread_create: backgound_process");
 	    endwin();
