@@ -2,6 +2,8 @@
 * Tlf - contest logging program for amateur radio operators
 * Copyright (C) 2001-2002-2003-2004 Rein Couperus <pa0rct@amsat.org>
 * 		2011-2012           Thomas Beierlein <tb@forth-ev.de>
+* 		2013 		    Fred DH5FS
+*               2013                Ervin Hegedus <airween@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -10,17 +12,17 @@
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-* GNU Library General Public License for more details.
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include "parse_logcfg.h"
-#include "speed_conversion.h"
 #include "tlf.h"
 #include "write_tone.h"
+#include "cw_utils.h"
 #include "speedup.h"
 #include "speeddown.h"
 #include <curses.h>
@@ -32,16 +34,18 @@
 #endif
 #include <ctype.h>
 #include "bandmap.h"
+#include "locator2longlat.h"
 
 extern int keyerport;
 extern char tonestr[];
-extern int speed, partials;
+extern int partials;
 extern int use_part;
 extern int contest;
 extern int portnum;
 extern int packetinterface;
 extern int tncport;
 extern int shortqsonr;
+extern char * cabrillo;
 
 int exist_in_country_list();
 
@@ -52,7 +56,7 @@ void KeywordNotSupported(char *keyword);
 void ParameterNeeded(char *keyword);
 void WrongFormat(char *keyword);
 
-#define  MAX_COMMANDS 158	/* commands in list */
+#define  MAX_COMMANDS 161	/* commands in list */
 
 
 int read_logcfg(void)
@@ -66,7 +70,6 @@ int read_logcfg(void)
     int status = PARSE_OK;
 
     contest = 0;
-    speed = 14;
     partials = 0;
     use_part = 0;
     keyerport = 0;
@@ -77,6 +80,11 @@ int read_logcfg(void)
     node = 0;
     shortqsonr = 0;
 
+    if (cabrillo != NULL) {
+	free(cabrillo);
+	cabrillo = NULL;
+    }
+
     strcpy(defltconf, PACKAGE_DATA_DIR);
     strcat(defltconf, "/logcfg.dat");
 
@@ -99,8 +107,8 @@ int read_logcfg(void)
 
     while ( fgets(inputbuffer, 120, fp) != NULL ) {
 
-	if ((inputbuffer[0] != '#') && (strlen(inputbuffer) > 1)) {	
-	    					/* skip comments and 
+	if ((inputbuffer[0] != '#') && (strlen(inputbuffer) > 1)) {
+	    					/* skip comments and
 						 * empty lines */
 	    status |= parse_logcfg(inputbuffer);
 	}
@@ -127,7 +135,7 @@ static int confirmation_needed;
 int parse_logcfg(char *inputbuffer)
 {
     extern int use_rxvt;
-    extern char message[15][80];
+    extern char message[][80];
     extern char ph_message[14][80];
     extern char sp_return[];
     extern char cq_return[];
@@ -139,12 +147,11 @@ int parse_logcfg(char *inputbuffer)
     extern int one_point;
     extern int two_point;
     extern int three_point;
-    extern int two_eu_three_dx_points;
     extern int exchange_serial;
     extern int country_mult;
     extern int wysiwyg_multi;
     extern int wysiwyg_once;
-    extern int fixedmult;
+    extern float fixedmult;
     extern int portable_x2;
     extern int trx_control;
     extern int rit;
@@ -155,7 +162,6 @@ int parse_logcfg(char *inputbuffer)
     extern int searchflg;
     extern int demode;
     extern int contest;
-    extern int speed;
     extern int weight;
     extern int txdelay;
     extern char tonestr[];
@@ -174,7 +180,6 @@ int parse_logcfg(char *inputbuffer)
 #ifdef HAVE_LIBHAMLIB
     extern rig_model_t myrig_model;
 #endif
-    extern int rig_port;
     extern char rigportname[];
     extern int rignumber;
     extern char rigconf[];
@@ -183,6 +188,7 @@ int parse_logcfg(char *inputbuffer)
     extern int netkeyer_port;
     extern char netkeyer_hostaddress[];
     extern char bc_hostaddress[MAXNODES][16];
+    extern char bc_hostservice[MAXNODES][16];
     extern int lan_active;
     extern char thisnode;
     extern int nodes;
@@ -208,7 +214,7 @@ int parse_logcfg(char *inputbuffer)
     extern int nob4;
     extern int noautocq;
     extern int show_time;
-    extern char keyer_device[];
+    extern char keyer_device[10];
     extern int use_vk;
     extern int wazmult;
     extern int itumult;
@@ -250,7 +256,8 @@ int parse_logcfg(char *inputbuffer)
     extern char rttyoutput[];
     extern int logfrequency;
     extern int ignoredupe;
-
+    extern char myqra[7];
+    
     char commands[MAX_COMMANDS][30] = {
 	"enable",		/* 0 */		/* deprecated */
 	"disable",				/* deprecated */
@@ -300,9 +307,9 @@ int parse_logcfg(char *inputbuffer)
 	"EDITOR",		/* 45 */
 	"PARTIALS",
 	"USEPARTIALS",
-	"POWERMULT_5",
-	"POWERMULT_2",
-	"POWERMULT_1",		/* 50 */
+	"POWERMULT_5",				/* deprecated */
+	"POWERMULT_2",				/* deprecated */
+	"POWERMULT_1",		/* 50 */	/* deprecated */
 	"MANY_CALLS",				/* deprecated */
 	"SERIAL_EXCHANGE",
 	"COUNTRY_MULT",
@@ -407,10 +414,13 @@ int parse_logcfg(char *inputbuffer)
 	"DIGIMODEM",
 	"LOGFREQUENCY",
 	"IGNOREDUPE",
-	"CW_TU_MSG",				/* deprecated */
-	"VKCWR",		/* 155 */	/* deprecated */
+	"CABRILLO",
+	"CW_TU_MSG",		/* 155 */	/* deprecated */
+	"VKCWR",				/* deprecated */
 	"VKSPR",				/* deprecated */
-	"NO_RST"
+	"NO_RST",
+	"MYQRA",
+	"POWERMULT"		/* 160 */
     };
 
     char **fields;
@@ -451,7 +461,7 @@ int parse_logcfg(char *inputbuffer)
     if (g_strv_length( fields ) == 2) { /* strip leading whitespace */
 	g_strchug( fields[1] );		/* from parameters */
     }
-    
+
     g_strlcpy( teststring, fields[0], sizeof(teststring) );
 
     for (ii = 0; ii < MAX_COMMANDS; ii++) {
@@ -507,14 +517,18 @@ int parse_logcfg(char *inputbuffer)
 		refreshp();
 		exit(1);
 	    }
-	    strcpy(call, fields[1]);
+	    /* strip NL and trailing whitespace */
+	    g_strlcpy( call, g_strchomp(fields[1]), 20 );
+	    /* as other code parts rely on a trailing NL on the call
+	     * we add back such a NL for now */
+	    strcat( call, "\n");
 	    // check that call sign can be found in cty database !!
 	    break;
 	}
-    case 17:{
+    case 17:
+    case 122:{
     	    PARAMETER_NEEDED(teststring);
-	    strcpy(whichcontest, fields[1]);
-	    whichcontest[strlen(whichcontest) - 1] = '\0';
+	    strcpy(whichcontest, g_strchomp(fields[1]));
 	    if (strlen(whichcontest) > 40) {
 		showmsg
 		    ("WARNING: contest name is too long! exiting...");
@@ -525,16 +539,13 @@ int parse_logcfg(char *inputbuffer)
 	}
     case 18:{
     	    PARAMETER_NEEDED(teststring);
-	    logfile[0] = '\0';
-	    strcat(logfile, fields[1]);
-	    logfile[strlen(logfile) - 1] = '\0';
+	    strcpy(logfile, g_strchomp(fields[1]));
 	    break;
 	}
     case 19:{
     	    PARAMETER_NEEDED(teststring);
-	    keyer_device[0] = '\0';
-	    strncat(keyer_device, fields[1], 9);
-	    keyer_device[strlen(keyer_device) - 1] = '\0';
+	    g_strlcpy(keyer_device, g_strchomp(fields[1]),
+		    sizeof(keyer_device));
 	    break;
 	}
     case 20:{		// Use the bandswitch output on parport0
@@ -674,7 +685,7 @@ int parse_logcfg(char *inputbuffer)
     	    PARAMETER_NEEDED(teststring);
 	    buff[0] = '\0';
 	    strncat(buff, fields[1], 2);
-	    speed = speed_conversion(atoi(buff));
+	    SetCWSpeed(atoi(buff));
 	    break;
 	}
     case 39:{
@@ -765,7 +776,7 @@ int parse_logcfg(char *inputbuffer)
 	    use_part = 1;
 	    break;
 	}
-    case 48:{
+    /*case 48:{
 	    fixedmult = 5;
 	    break;
 	}
@@ -776,7 +787,7 @@ int parse_logcfg(char *inputbuffer)
     case 50:{
 	    fixedmult = 1;
 	    break;
-	}
+	} */
     case 51:{
 	    KeywordNotSupported(teststring);
 	    break;
@@ -790,7 +801,7 @@ int parse_logcfg(char *inputbuffer)
 	    break;
 	}
     case 54:{
-	    two_eu_three_dx_points = 1;
+	    KeywordNotSupported(teststring);
 	    break;
 	}
     case 55:{
@@ -803,8 +814,7 @@ int parse_logcfg(char *inputbuffer)
 	}
     case 57:{
 	    PARAMETER_NEEDED(teststring);
-	    strncpy(pr_hostaddress, fields[1], 47);
-	    pr_hostaddress[strlen(pr_hostaddress) - 1] = '\0';
+	    g_strlcpy(pr_hostaddress, g_strchomp(fields[1]), 48);
 	    break;
 	}
     case 58:{
@@ -864,11 +874,7 @@ int parse_logcfg(char *inputbuffer)
 	    PARAMETER_NEEDED(teststring);
 	    buff[0] = '\0';
 	    strcat(buff, fields[1]);
-	    if (buff[0] == '0' || buff[0] == '1') {
-		rig_port = atoi(buff);
-	    } else {
-		strncpy(rigportname, buff, 39);
-	    }
+	    strncpy(rigportname, buff, 39);
 	    break;
 	}
     case 65:{
@@ -882,17 +888,25 @@ int parse_logcfg(char *inputbuffer)
 	}
     case 67:{
 	    PARAMETER_NEEDED(teststring);
-	    strncpy(netkeyer_hostaddress, fields[1], 16);
-	    netkeyer_hostaddress[strlen(netkeyer_hostaddress) -
-				 1] = '\0';
+	    g_strlcpy(netkeyer_hostaddress, g_strchomp(fields[1]), 16);
 	    break;
 	}
     case 68:{
 	    PARAMETER_NEEDED(teststring);
 	    if (node < MAXNODES) {
-		strncpy(bc_hostaddress[node], fields[1], 16);
-		bc_hostaddress[node][strlen(bc_hostaddress[node]) -
-				     1] = '\0';
+		/* split host name and port number, separated by colon */
+		char **an_fields;
+		an_fields = g_strsplit(fields[1], ":", 2);
+		/* copy host name */
+		g_strlcpy(bc_hostaddress[node], g_strchomp(an_fields[0]),
+			    sizeof(bc_hostaddress[0]));
+		if (an_fields[1] != NULL) {
+		    /* copy host port, if found */
+		    g_strlcpy(bc_hostservice[node], g_strchomp(an_fields[1]),
+				sizeof(bc_hostservice[0]));
+		}
+		g_strfreev(an_fields);
+
 		if (node++ < MAXNODES)
 		    nodes++;
 	    }
@@ -900,8 +914,13 @@ int parse_logcfg(char *inputbuffer)
 	    break;
 	}
     case 69:{
+	    char c;
 	    PARAMETER_NEEDED(teststring);
-	    thisnode = fields[1][0];
+	    c = toupper(fields[1][0]);
+	    if (c >= 'A' && c <= 'H')
+		thisnode = c;
+	    else
+		WrongFormat(teststring);
 	    break;
 	}
     case 70:{
@@ -947,9 +966,7 @@ int parse_logcfg(char *inputbuffer)
 	}
     case 87:{
 	    PARAMETER_NEEDED(teststring);
-	    multsfile[0] = '\0';
-	    strncat(multsfile, fields[1], 79);
-	    g_strchomp(multsfile);
+	    g_strlcpy(multsfile, g_strchomp(fields[1]), 80);
 	    multlist = 1;
 	    universal = 1;
 	    break;
@@ -1023,7 +1040,7 @@ int parse_logcfg(char *inputbuffer)
 
 			/* accept only a line starting with the contest name
 			 * (CONTEST=) followed by ':' */
-			if (strncasecmp (buffer, whichcontest, 
+			if (strncasecmp (buffer, whichcontest,
 				strlen(whichcontest) - 1) == 0) {
 
 			    strncpy(multiplier_list,
@@ -1094,10 +1111,10 @@ int parse_logcfg(char *inputbuffer)
 	    PARAMETER_NEEDED(teststring);
 	    g_strlcpy(c_temp, fields[1], sizeof(c_temp));
 	    if (dx_cont_points == -1)
-		dx_cont_points = atoi(c_temp);
+	    dx_cont_points = atoi(c_temp);
 
 	    break;
-	   }
+       }
 /* end LZ3NY mod */
     case 101:{		// show time in searchlog window
 		show_time = 1;
@@ -1107,30 +1124,16 @@ int parse_logcfg(char *inputbuffer)
 		use_rxvt = 1;
 		break;
 	    }
-    case 103 ... 111:{	// get phone messages
+    case 103 ... 116:{	// get phone messages
 	    PARAMETER_NEEDED(teststring);
-		strncpy(ph_message[ii - 103], fields[1], 70);
-		ph_message[ii - 103][strlen(ph_message[ii - 103]) -
-				     1] = '\0';
-		mvprintw(15, 5, "A: Phone message #%d is %s", ii - 103, ph_message[ii - 103]);	// (W9WI)
-		refreshp();
-		//                             system ("sleep 2");
-		if (strlen(ph_message[ii - 103]) > 0)
-		    use_vk = 1;
-		break;
-	    }
-    case 112 ... 116:{	// get phone messages
-	    PARAMETER_NEEDED(teststring);
-		strncpy(ph_message[ii - 103], fields[1], 39);
-		ph_message[ii - 103][strlen(ph_message[ii - 103]) -
-				     1] = '\0';
-		mvprintw(15, 5, "B: Phone message #%d is %s", ii - 103, ph_message[ii - 103]);	// (W9WI)
-		refreshp();
-		//                             system ("sleep 2");
-		if (strlen(ph_message[ii - 103]) > 0)
-		    use_vk = 1;
-		break;
-	    }
+	    g_strlcpy(ph_message[ii - 103], g_strchomp(fields[1]), 71);
+	    mvprintw(15, 5, "A: Phone message #%d is %s", ii - 103, ph_message[ii - 103]);	// (W9WI)
+	    refreshp();
+	    //                             system ("sleep 2");
+	    if (strlen(ph_message[ii - 103]) > 0)
+		use_vk = 1;
+	    break;
+	}
     case 117:{		// WAZ Zone is a Multiplier
 		wazmult = 1;
 		break;
@@ -1139,7 +1142,7 @@ int parse_logcfg(char *inputbuffer)
 		itumult = 1;
 		break;
 	    }
-    case 119:{		// CQ Delay (sec)
+    case 119:{		// CQ Delay (0.5 sec)
 		PARAMETER_NEEDED(teststring);
 		buff[0] = '\0';
 		strncpy(buff, fields[1], 3);
@@ -1158,19 +1161,6 @@ int parse_logcfg(char *inputbuffer)
 		exc_cont = 1;
 		break;
 	    }
-    case 122:{
-		PARAMETER_NEEDED(teststring);
-		strcpy(whichcontest, fields[1]);	// RULES=
-		whichcontest[strlen(whichcontest) - 1] = '\0';
-		if (strlen(whichcontest) > 40) {
-		    showmsg
-			("WARNING: contest name is too long! exiting...");
-		    sleep(5);
-		    exit(1);
-		}
-		setcontest();
-		break;
-	    }
     case 123:{		// don't use auto_cq
 		noautocq = 1;
 		break;
@@ -1191,8 +1181,7 @@ int parse_logcfg(char *inputbuffer)
 		    sleep(5);
 		    exit(1);
 		}
-		strncpy(rigconf, fields[1], 79);	// RIGCONF=
-		rigconf[strlen(rigconf) - 1] = '\0';	// chop LF
+		g_strlcpy(rigconf, g_strchomp(fields[1]), 80);	// RIGCONF=
 		break;
 	    }
     case 127:{		// define color GREEN (header)
@@ -1221,22 +1210,18 @@ int parse_logcfg(char *inputbuffer)
 	    }
     case 133:{		// define name of synclogfile
 		PARAMETER_NEEDED(teststring);
-		synclogfile[0] = '\0';
-		strcat(synclogfile, fields[1]);
-		synclogfile[strlen(synclogfile) - 1] = '\0';
+		strcpy(synclogfile, g_strchomp(fields[1]));
 		break;
 	    }
     case 134:{		//SSBPOINTS=
 		PARAMETER_NEEDED(teststring);
-		buff[0] = '\0';
-		strcat(buff, fields[1]);
+		strcpy(buff, fields[1]);
 		ssbpoints = atoi(buff);
 		break;
 	    }
     case 135:{		//CWPOINTS=
 		PARAMETER_NEEDED(teststring);
-		buff[0] = '\0';
-		strcat(buff, fields[1]);
+		strcpy(buff, fields[1]);
 		cwpoints = atoi(buff);
 		break;
 	    }
@@ -1274,17 +1259,14 @@ int parse_logcfg(char *inputbuffer)
 	    }
     case 139:{		// dsp for s-meter
 		PARAMETER_NEEDED(teststring);
-		strncpy(sc_device, fields[1],
-			sizeof(sc_device) - 1);
-		sc_device[strlen(sc_device) - 1] = '\0';
+		g_strlcpy(sc_device, g_strchomp(fields[1]), sizeof(sc_device));
 		break;
 	    }
     case 140:{
 		PARAMETER_NEEDED(teststring);
 		keyerport = MFJ1278_KEYER;
-		strncpy(controllerport, fields[1],
-			sizeof(controllerport) - 1);
-		controllerport[strlen(controllerport) - 1] = '\0';
+		g_strlcpy(controllerport, g_strchomp(fields[1]),
+			sizeof(controllerport));
 		break;
 	    }
     case 141:{
@@ -1293,14 +1275,13 @@ int parse_logcfg(char *inputbuffer)
 		break;
 	    }
     case 142:{
-		keyerport = ORION_KEYER;
+		KeywordNotSupported(teststring);
 		break;
 	    }
     case 143:{
 		PARAMETER_NEEDED(teststring);
-		strncpy(exchange_list, fields[1],
-			sizeof(exchange_list) - 1);
-		exchange_list[strlen(exchange_list) - 1] = '\0';
+		g_strlcpy(exchange_list, g_strchomp(fields[1]),
+			sizeof(exchange_list));
 		break;
 	    }
     case 144:{
@@ -1327,22 +1308,18 @@ int parse_logcfg(char *inputbuffer)
     case 149:{
 		PARAMETER_NEEDED(teststring);
 		keyerport = GMFSK;
-		strncpy(controllerport, fields[1],
-			sizeof(controllerport) - 1);
-		controllerport[strlen(controllerport) - 1] = '\0';
+		g_strlcpy(controllerport, g_strchomp(fields[1]),
+			sizeof(controllerport));
 		break;
 	    }
     case 150:{		// start in digital mode
 		trxmode = DIGIMODE;
-		modem_mode[0] = '\0';
-		strcat(modem_mode, "RTTY");
+		strcpy(modem_mode, "RTTY");
 		break;
 	    }
     case 151:{
 		PARAMETER_NEEDED(teststring);
-		rttyoutput[0] = '\0';
-		strncat(rttyoutput, fields[1], 110);
-		rttyoutput[strlen(rttyoutput) - 1] = '\0';
+		g_strlcpy(rttyoutput, g_strchomp(fields[1]), 111);
 		break;
 	    }
     case 152:{
@@ -1353,17 +1330,45 @@ int parse_logcfg(char *inputbuffer)
 		ignoredupe = 1;
 		break;
 	    }
-    case 154:
+    case 154:{		/* read name of cabrillo format to use */
+
+		if (cabrillo != NULL) {
+		    free(cabrillo);	/* free old string if already set */
+		    cabrillo = NULL;
+		}
+	    	cabrillo = strdup(g_strchomp(fields[1]));
+    		break;
+	    }
     case 155:
-    case 156: {
+    case 156:
+    case 157:{
 		KeywordNotSupported(teststring);
 		break;
 	    }
-    case 157:{
+    case 158:{
 		 no_rst = 1;
 		 break;
 	    }
+    case 159:{
+		PARAMETER_NEEDED(teststring);
+		strcpy(myqra, fields[1]);
 
+		if (check_qra(myqra) > 0) {
+		    showmsg
+			("WARNING: Invalid MYQRA parameters! exiting...");
+		    sleep(5);
+		    exit(1);
+		}
+		break;
+	    }
+    case 160:{
+    	    PARAMETER_NEEDED(teststring);
+	    if (fixedmult == 0.0 && atof(fields[1]) > 0.0) {
+	      fixedmult = atof(fields[1]);
+	    }
+	    break;
+	}
+	    
     default: {
 		KeywordNotSupported(g_strstrip(inputbuffer));
 		break;
@@ -1377,105 +1382,12 @@ int parse_logcfg(char *inputbuffer)
 }
 
 
-int speed_conversion(int cwspeed)
-{
-
-    int x;
-
-    switch (cwspeed) {
-
-    case 0 ... 6:{
-	    x = 0;
-	    break;
-	}
-    case 7 ... 12:{
-	    x = 1;
-	    break;
-	}
-    case 13 ... 14:{
-	    x = 2;
-	    break;
-	}
-    case 15 ... 16:{
-	    x = 3;
-	    break;
-	}
-    case 17 ... 18:{
-	    x = 4;
-	    break;
-	}
-    case 19 ... 20:{
-	    x = 5;
-	    break;
-	}
-    case 21 ... 22:{
-	    x = 6;
-	    break;
-	}
-    case 23 ... 24:{
-	    x = 7;
-	    break;
-	}
-    case 25 ... 26:{
-	    x = 8;
-	    break;
-	}
-    case 27 ... 28:{
-	    x = 9;
-	    break;
-	}
-    case 29 ... 30:{
-	    x = 10;
-	    break;
-	}
-    case 31 ... 36:{
-	    x = 11;
-	    break;
-	}
-    case 37 ... 42:{
-	    x = 12;
-	    break;
-	}
-    case 43 ... 48:{
-	    x = 13;
-	    break;
-	}
-    case 49 ... 50:{
-	    x = 14;
-	    break;
-	}
-    case 51 ... 54:{
-	    x = 15;
-	    break;
-	}
-    case 55 ... 57:{
-	    x = 16;
-	    break;
-	}
-    case 58 ... 60:{
-	    x = 17;
-	    break;
-	}
-    case 61 ... 63:{
-	    x = 18;
-	    break;
-	}
-    default:{
-	    x = 19;
-	    break;
-	}
-    }
-
-    return (x);
-}
-
-
-/** Complain about problems in configuration 
+/** Complain about problems in configuration
  *
  * Complains in standout mode about some problem. Beep and wait for
- * 2 seconds 
+ * 2 seconds
  *
- * \param msg  The reason for the problem to be shown 
+ * \param msg  The reason for the problem to be shown
  */
 void Complain(char *msg) {
     attron(A_STANDOUT);
