@@ -9,12 +9,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 	/* ------------------------------------------------------------
 	 *        Initialize  call array for dupes
@@ -37,7 +37,8 @@ int readcalls(void)
     char bndbuf[20];
     char zonebuf[3];
     char checkcall[20];
-    int i = 0, k = 0, l = 0, n = 0, r = 0, s = 0;
+    int i = 0, l = 0, n = 0, r = 0, s = 0;
+    unsigned int k = 0;
     int m = 0;
     int t = 0, tt = 0;
     int z = 0;
@@ -57,8 +58,11 @@ int readcalls(void)
     for (s = 0; s < MAX_QSOS; s++)
 	qsos[s][0] = '\0';
 
-    for (i = 0; i < MAX_CALLS; i++)
+    for (i = 0; i < MAX_CALLS; i++) {
 	callarray[i][0] = '\0';
+	call_band[i] = 0;
+	call_country[i] = -1;
+    }
 
     for (i = 1; i <= MAX_DATALINES - 1; i++)
 	countries[i] = 0;
@@ -84,6 +88,7 @@ int readcalls(void)
 	mvprintw(5, 0, "Error opening logfile.\n");
 	refreshp();
 	sleep(2);
+	exit(1);
     }
     i = 0;
     k = 0;
@@ -103,15 +108,14 @@ int readcalls(void)
 	}
 
 	strcat(inputbuffer, "                                                  ");	/* repair the logfile */
-	inputbuffer[79] = ' ';
-	inputbuffer[80] = '\0';
+	inputbuffer[LOGLINELEN-1] = '\0';
 
 	for (t = 0; t <= strlen(inputbuffer); t++) {
 	    if (inputbuffer[t] == '\n')
 		inputbuffer[t] = ' ';
 	}
 
-	strncpy(qsos[s], inputbuffer, 81);
+	strncpy(qsos[s], inputbuffer, LOGLINELEN);
 	s++;
 
 	if (inputbuffer[0] == ';')
