@@ -9,12 +9,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 	/* ------------------------------------------------------------
 	 *        Search log for calls / bands  /  countries
@@ -31,7 +31,7 @@
 
 PANEL *search_panel;
 WINDOW *search_win;
-int initialized = 0;
+static int initialized = 0;
 
 void show_needed_sections(void);
 
@@ -102,7 +102,7 @@ void searchlog(char *searchstring)
     extern int trxmode;
     extern long int nr_callmastercalls;
     extern char callmasterarray[MAX_CALLMASTER][14];
-    extern char qsos[MAX_QSOS][82];
+    extern char qsos[MAX_QSOS][LOGLINELEN+1];
     extern char hiscall[];
     extern char zone_export[];
     extern char zone_fix[];
@@ -116,8 +116,8 @@ void searchlog(char *searchstring)
     int yy;
     int bandnr;
     int bm[6];
-    char s_inputbuffer[82] = "";
-    char s_inputbuffercpy[82] = "";
+    char s_inputbuffer[LOGLINELEN+1] = "";
+    char s_inputbuffercpy[LOGLINELEN+1] = "";
     char printres[14] = "";
     char *loc;
     dxcc_data *dx;
@@ -164,7 +164,7 @@ void searchlog(char *searchstring)
 		mixedmode == 0) {
 		// ist letzterTest korrekt?
 
-		strncpy(s_inputbuffer, qsos[qso_index], 81);
+		strncpy(s_inputbuffer, qsos[qso_index], LOGLINELEN);
 
 		if (strstr(s_inputbuffer, hiscall) != 0) {
 		    strcpy(searchresult[srch_index], s_inputbuffer);
@@ -275,14 +275,14 @@ void searchlog(char *searchstring)
 
 	dupe = NODUPE;
 
-	wbkgd( search_win, (chtype)(' ' | COLOR_PAIR(7)) );
+	wbkgd( search_win, (chtype)(' ' | COLOR_PAIR(C_LOG)) );
 	werase( search_win );
 
 	wnicebox(search_win, 0, 0, 6, 37, "Worked");
 
-	wattrset(search_win, COLOR_PAIR(7) | A_STANDOUT );
+	wattrset(search_win, COLOR_PAIR(C_LOG) | A_STANDOUT );
 	for (i = 0; i < 6; i++)
-	    mvwprintw(search_win, i + 1, 1, 
+	    mvwprintw(search_win, i + 1, 1,
 		    "                                     ");
 
 	mvwprintw(search_win, 1, 1, " 10");
@@ -294,7 +294,7 @@ void searchlog(char *searchstring)
 
 	refreshp();
 
-	wattrset(search_win, COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+	wattrset(search_win, COLOR_PAIR(C_WINDOW) | A_STANDOUT);
 
 	k = 0;
 
@@ -311,8 +311,8 @@ void searchlog(char *searchstring)
 		    if (ignoredupe == 0) {
 
 			if (mixedmode == 0) {
-			    wattron(search_win, 
-				    COLOR_PAIR(DUPECOLOR) | A_STANDOUT);
+			    wattrset(search_win,
+				    COLOR_PAIR(C_DUPE));
 			    dupe = ISDUPE;
 			    beep();
 			} else {
@@ -320,8 +320,8 @@ void searchlog(char *searchstring)
 				 (trxmode == CWMODE)) ||
 				((s_inputbuffer[3] == 'S')
 				 && (trxmode == SSBMODE))) {
-				wattron(search_win, 
-					COLOR_PAIR(DUPECOLOR) | A_STANDOUT);
+				wattrset(search_win,
+					COLOR_PAIR(C_DUPE));
 				dupe = ISDUPE;
 				beep();
 			    }
@@ -360,7 +360,7 @@ void searchlog(char *searchstring)
 		    z = z1;
 	    }
 
-	    wattron(search_win, COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+	    wattron(search_win, COLOR_PAIR(C_WINDOW) | A_STANDOUT);
 
 	    if ((partials == 1) && (strlen(hiscall) >= 2)) {
 		if (strlen(s_inputbuffer) != 0)
@@ -391,7 +391,7 @@ void searchlog(char *searchstring)
 	    }
 	}
 
-	wattron(search_win, COLOR_PAIR(COLOR_YELLOW));
+	wattron(search_win, COLOR_PAIR(C_BORDER));
 
 	mvwprintw(search_win, 7, 2, dx->countryname);
 	mvwprintw(search_win, 7, 32, "%02d", dx->cq);
@@ -409,7 +409,7 @@ void searchlog(char *searchstring)
 	}
 
 	/* print worked zones and countrys for each band in checkwindow */
-	wattron(search_win, COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+	wattron(search_win, COLOR_PAIR(C_HEADER) | A_STANDOUT);
 
 	if (cqww == 1 || contest == 0 || pacc_pa_flg == 1) {
 
@@ -506,32 +506,32 @@ void searchlog(char *searchstring)
 	    j = 0;
 
 	    if (use_rxvt == 0)
-		attron(COLOR_PAIR(COLOR_WHITE | A_BOLD | A_STANDOUT));
+		attron(COLOR_PAIR(C_LOG) | A_BOLD | A_STANDOUT);
 	    else
-		attron(COLOR_PAIR(COLOR_WHITE | A_STANDOUT));
+		attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 
 	    for (k = 1; k <= 5; k++) {
 		mvprintw(k, 0, "%s",
 			 "                                        ");
 	    }
-	    attron(COLOR_PAIR(COLOR_MAGENTA) | A_STANDOUT);
+	    attrset(COLOR_PAIR(C_DUPE));
 	    mvprintw(1, 1, "??");
-	    attron(COLOR_PAIR(COLOR_WHITE | A_STANDOUT));
+	    attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 
 	    refreshp();
 
 	    j = 0;
 	    m = 0;
-	    
+
 	    /* check what we have worked first */
-	    /** \todo the method below parses through the array of already 
+	    /** \todo the method below parses through the array of already
 	     * looked up search results from the search window. That is quick
 	     * but has the drawback, that we have no band information and
 	     * therefore print some entries more than once.
-	     * Better would be to lookup the partial call in the array of 
-	     * worked stations 'callarray' - it is there only once and we can 
+	     * Better would be to lookup the partial call in the array of
+	     * worked stations 'callarray' - it is there only once and we can
 	     * also see from 'call_band' if it is a dupe here.
-	     * be aware of the problem of marking it dupe only for a complete 
+	     * be aware of the problem of marking it dupe only for a complete
 	     * match.
 	     */
 	    for (m = 0; m < srch_index; m++) {
@@ -546,13 +546,19 @@ void searchlog(char *searchstring)
 			    *loc = '\0';
 
 			if (dupe == ISDUPE) {
-			    attron(COLOR_PAIR(COLOR_MAGENTA) | A_STANDOUT);
+			    attrset(COLOR_PAIR(C_DUPE));
 			} else {
-			    attron(COLOR_PAIR
-				   (COLOR_YELLOW | A_BOLD | A_STANDOUT));
+			    if (use_rxvt == 0)
+				attron(COLOR_PAIR
+				       (C_BORDER) | A_BOLD | A_STANDOUT);
+			    else
+				attron(COLOR_PAIR
+				       (C_BORDER) | A_STANDOUT);
 			}
 			mvprintw(xwin + l, ywin + j, "%s ", printres);
-			attron(COLOR_PAIR(COLOR_WHITE | A_STANDOUT));
+			attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
+
+			attroff(A_BOLD);
 
 			refreshp();
 
@@ -578,12 +584,10 @@ void searchlog(char *searchstring)
 		    if ( strstr(callmasterarray[m], hiscall) != NULL ) {
 
 			if (use_rxvt == 0)
-			    attron(COLOR_PAIR
-				   (COLOR_WHITE | A_BOLD |
-				    A_STANDOUT));
+			    attron(COLOR_PAIR(C_LOG) | A_BOLD |
+				    A_STANDOUT);
 			else
-			    attron(COLOR_PAIR
-				   (COLOR_WHITE | A_STANDOUT));
+			    attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 
 			mvprintw(xwin + l, ywin + j, "%s  ",
 				 callmasterarray[m]);
@@ -608,9 +612,9 @@ void searchlog(char *searchstring)
 	    if ((j <= 13) && (l == 0) && (use_part == 1) && (block_part == 0)) {
 
 		if (use_rxvt == 0)
-		    attron(COLOR_PAIR(COLOR_GREEN | A_BOLD | A_STANDOUT));
+		    attron(COLOR_PAIR(C_HEADER) | A_BOLD | A_STANDOUT);
 		else
-		    attron(COLOR_PAIR(COLOR_GREEN | A_STANDOUT));
+		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 
 		mvprintw(13, 0, s_inputbuffercpy);
 		if (strlen(s_inputbuffercpy) > strlen(hiscall)) {
@@ -629,7 +633,7 @@ void searchlog(char *searchstring)
 
 	if (dupe == ISDUPE) {
 	    isdupe = 1;		// LZ3NY auto-b4 patch
-	    attron(COLOR_PAIR(DUPECOLOR) | A_STANDOUT);
+	    attrset(COLOR_PAIR(C_DUPE));
 	    mvprintw(12, 29, hiscall);
 	    refreshp();
 	    usleep(100000);
@@ -735,9 +739,9 @@ void show_needed_sections(void)
 	cnt = 0;
 
 	if (use_rxvt == 0)
-	    wattron(search_win, COLOR_PAIR(COLOR_CYAN) | A_BOLD | A_STANDOUT);
+	    wattron(search_win, COLOR_PAIR(C_WINDOW) | A_BOLD | A_STANDOUT);
 	else
-	    wattron(search_win, COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+	    wattron(search_win, COLOR_PAIR(C_WINDOW) | A_STANDOUT);
 
 	for (j = 1; j < 7; j++)
 	    mvwprintw(search_win, j, 1, "                                     ");
@@ -764,10 +768,10 @@ void show_needed_sections(void)
 		    mprint[3] = '\0';
 
 		    if (use_rxvt == 0)
-			wattron(search_win, COLOR_PAIR(COLOR_CYAN) | A_BOLD |
+			wattron(search_win, COLOR_PAIR(C_WINDOW) | A_BOLD |
 			       A_STANDOUT);
 		    else
-			wattron(search_win, COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+			wattron(search_win, COLOR_PAIR(C_WINDOW) | A_STANDOUT);
 
 		    if (strlen(mprint) > 1)
 			mvwprintw(search_win, vert, (hor * 4) + 2, "%s ", mprint);
@@ -791,9 +795,9 @@ void OnLowerSearchPanel(int x, char *str)
     extern int use_rxvt;
 
     if (use_rxvt == 0)
-	wattrset(search_win, COLOR_PAIR(COLOR_YELLOW) | A_BOLD);
+	wattrset(search_win, COLOR_PAIR(C_BORDER) | A_BOLD);
     else
-	wattrset(search_win, COLOR_PAIR(COLOR_YELLOW));
+	wattrset(search_win, COLOR_PAIR(C_BORDER));
 
     mvwprintw(search_win, 7, x, str);
 }
