@@ -9,12 +9,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 /* ------------------------------------------------------------------------
 *    send the text buffer to the keyer  driver
@@ -22,19 +22,21 @@
 ---------------------------------------------------------------------------*/
 #include "sendbuf.h"
 #include "netkeyer.h"
+#include <glib.h>
+
+char buffer[81];
 
 void sendbuf(void)
 {
 
     extern int trxmode;
-    extern char buffer[81];
     extern char call[20];
     extern char hiscall[20];
     extern char his_rst[];
     extern char qsonrstr[5];
     extern int shortqsonr;
     extern int searchflg;
-    extern char termbuf[81];
+    extern char termbuf[];
     extern char backgrnd_str[];
     extern int bufloc;
     extern char wkeyerbuffer[];
@@ -185,7 +187,7 @@ void sendbuf(void)
 //              }
 	}
 
-	attron(COLOR_PAIR(7) | A_STANDOUT);
+	attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 
 	if (simulator == 0)
 	    strncat(printlinebuffer, termbuf, strlen(termbuf));
@@ -206,7 +208,7 @@ void sendbuf(void)
 	getyx(stdscr, cury, curx);
 	attron(COLOR_PAIR(COLOR_RED) | A_STANDOUT);
 	mvaddstr(0, 0, "x");
-	attron(COLOR_PAIR(COLOR_WHITE));
+	attron(COLOR_PAIR(C_LOG));
 	mvaddstr(cury, curx, "");
 	refreshp();
 
@@ -220,10 +222,10 @@ void sendbuf(void)
 			    buffer[i] = 13;
 		    for (i = 0; i < strlen(buffer); i++)
 			if (buffer[i] == 123)
-			    buffer[i] = 20;
+			    buffer[i] = 20;	/* ctrl-t */
 		    for (i = 0; i < strlen(buffer); i++)
 			if (buffer[i] == 125)
-			    buffer[i] = 18;
+			    buffer[i] = 18;	/* ctrl-r */
 		}
 		strcat(wkeyerbuffer, buffer);
 		buffer[0] = '\0';
@@ -254,9 +256,9 @@ void sendbuf(void)
 	}
 
 	getyx(stdscr, cury, curx);
-	attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+	attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 	mvaddstr(0, 0, " ");
-	attron(COLOR_PAIR(COLOR_WHITE));
+	attron(COLOR_PAIR(C_LOG));
 	mvaddstr(cury, curx, "");
 
 	if (simulator == 0) {
@@ -269,3 +271,17 @@ void sendbuf(void)
 	bufloc = 0;
     }
 }
+
+
+/** \brief send message
+ *
+ * Send the message via CW or DIGI mode, but only if not empty
+ * \parm msg message to send
+ */
+void sendmessage(char *msg)
+{
+    if (strlen(msg) != 0) {
+	g_strlcat(buffer, msg, sizeof(buffer));
+	sendbuf();
+    }
+}
